@@ -1,6 +1,5 @@
 package Crypt::TimestampedData;
-$Crypt::TimestampedData::VERSION = '0.01_05'; # TRIAL
-$Crypt::TimestampedData::VERSION = '0.0105';
+$Crypt::TimestampedData::VERSION = '0.01';
 use strict;
 use warnings;
 
@@ -14,7 +13,7 @@ Crypt::TimestampedData - Read and write TimeStampedData files (.TSD, RFC 5544)
 
 =head1 VERSION
 
-version 0.01_05
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -126,8 +125,6 @@ This distribution includes several command-line scripts for working with TimeSta
 
 =item * C<tsd-info> - Display information about a .tsd file
 
-=item * C<tsd-timestamp> - Obtain a timestamp from FreeTSA.org
-
 =back
 
 =head2 Windows Usage
@@ -137,7 +134,6 @@ On Windows systems, scripts must be executed with Perl explicitly:
   perl tsd-create --help
   perl tsd-extract document.tsd
   perl tsd-info document.tsd
-  perl tsd-timestamp document.pdf
 
 =head2 Unix/Linux Usage
 
@@ -146,7 +142,6 @@ On Unix/Linux systems, scripts can be executed directly:
   tsd-create --help
   tsd-extract document.tsd
   tsd-info document.tsd
-  tsd-timestamp document.pdf
 
 =head1 REQUIREMENTS
 
